#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   libxml-sax
version:                0.7.6
visibility:             public
id:                     libxml-sax-0.7.6-CeeCeSAJ8CqIBF9LypK1rX
key:                    libxml-sax-0.7.6-CeeCeSAJ8CqIBF9LypK1rX
license:                MIT
maintainer:             jmillikin@gmail.com
author:                 John Millikin
stability:              experimental
homepage:               https://git.singpolyma.net/haskell-libxml-sax
synopsis:               Bindings for the libXML2 SAX interface
category:               Foreign, Text, XML, Parsing
abi:                    8be088c308de0e0674fac11c7f767261
exposed:                True
exposed-modules:        Text.XML.LibXML.SAX
import-dirs:            /usr/lib/ghc-9.6.6/site-local/libxml-sax-0.7.6
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/libxml-sax-0.7.6 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/libxml-sax-0.7.6 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-libxml-sax
hs-libraries:           HSlibxml-sax-0.7.6-CeeCeSAJ8CqIBF9LypK1rX
extra-libraries:        xml2 xml2
extra-libraries-static: xml2 m z icuuc icudata pthread m
include-dirs:           /usr/include/libxml2 /usr/include
depends:
    base-4.18.2.1 bytestring-0.11.5.3 text-2.0.2
    xml-types-0.3.8-ISf6rjkeTjSFXsXdIGBwau

haddock-interfaces:     /usr/share/doc/haskell-libxml-sax/html/libxml-sax.haddock
haddock-html:           /usr/share/doc/haskell-libxml-sax/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

